/*!
 * @nuxt/typescript-edge v2.4.0-25806248.43ce8e97 (c) 2016-2019

 * - All the amazing contributors
 * Released under the MIT License.
 * Website: https://nuxtjs.org
*/
'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

const path = require('path');
const enquirer = require('enquirer');
const fsExtra = require('fs-extra');
const chalk = _interopDefault(require('chalk'));
const consola = _interopDefault(require('consola'));
const env = _interopDefault(require('std-env'));
const tsNode = require('ts-node');

async function generateTsConfigIfMissing(rootDir) {
  const tsConfigPath = path.resolve(rootDir, 'tsconfig.json');

  if (!fsExtra.existsSync(tsConfigPath)) {
    const { confirmGeneration } = await enquirer.prompt({
      type: 'confirm',
      name: 'confirmGeneration',
      message: `Missing ${chalk.bold.blue('tsconfig.json')} in ${rootDir === process.cwd() ? 'current directory' : chalk.bold.green(path.resolve(rootDir))}, generate it ?`,
      initial: true,
      skip: env.minimal
    });

    if (confirmGeneration) {
      const configToExtend = '@nuxt/typescript-edge';
      await fsExtra.writeJSON(tsConfigPath, {
        extends: configToExtend,
        compilerOptions: {
          baseUrl: '.',
          types: [
            '@types/node',
            '@nuxt/vue-app-edge'
          ]
        }
      }, { spaces: 2 });
      consola.info(`Extending ${chalk.bold.blue(`node_modules/${configToExtend}/tsconfig.json`)}`);
      consola.success(`Generated successfully at ${chalk.bold.green(path.resolve(rootDir, 'tsconfig.json'))}`);
    }
  }
}

function registerTsNode() {
  // https://github.com/TypeStrong/ts-node
  tsNode.register();
}

async function setup(rootDir) {
  await generateTsConfigIfMissing(rootDir);
  registerTsNode();
}

exports.setup = setup;
